@@ -7,16 +7,17 @@ import os
 os.environ["MKL_NUM_THREADS"] = "1"
 os.environ["NUMEXPR_NUM_THREADS"] = "1"
 os.environ["OMP_NUM_THREADS"] = "1"
-
-import numpy as np
-import pandas as pd
-
-from arch import arch_model
 from collections import ChainMap
 from functools import partial
 from itertools import groupby
 from math import log, e
 from multiprocessing import cpu_count, Pool
+from typing import List, Dict, Optional, Callable
+
+import numpy as np
+import pandas as pd
+from antropy import spectral_entropy
+from arch import arch_model
 from scipy.optimize import minimize_scalar
 from sklearn.linear_model import LinearRegression
 from statsmodels.api import add_constant, OLS
@@ -24,15 +25,11 @@ from statsmodels.tsa.ar_model import AR
 from statsmodels.tsa.holtwinters import ExponentialSmoothing
 from statsmodels.tsa.seasonal import STL
 from statsmodels.tsa.stattools import acf, pacf, kpss
-from supersmoother import supersmoother
-from typing import List, Dict, Optional, Callable
+from supersmoother import SuperSmoother
 
-from .utils import (
-    embed, FREQS, hurst_exponent,
-    lambda_coef_var, poly,
-    scalets, spectral_entropy,
-    terasvirta_test, ur_pp
-)
+from .utils import (embed, FREQS, hurst_exponent,
+                    lambda_coef_var, poly,
+                    scalets, terasvirta_test, ur_pp)
 
 
 def acf_features(x: np.array, freq: int = 1) -> Dict[str, float]:
@@ -191,10 +188,6 @@ def entropy(x: np.array, freq: int = 1, base: float = e) -> Dict[str, float]:
     -------
     dict
         'entropy': Wrapper of the function spectral_entropy.
-
-    References
-    ----------
-    [1] https://raphaelvallat.com/entropy/build/html/index.html
     """
     try:
         with np.errstate(divide='ignore'):
@@ -310,7 +303,17 @@ def heterogeneity(x: np.array, freq: int = 1) -> Dict[str, float]:
     try:
         x_whitened = AR(x).fit(maxlag=order_ar, ic='aic', trend='c').resid
     except:
-        x_whitened = AR(x).fit(maxlag=order_ar, ic='aic', trend='nc').resid
+        try:
+            x_whitened = AR(x).fit(maxlag=order_ar, ic='aic', trend='nc').resid
+        except:
+            output = {
+                'arch_acf': np.nan,
+                'garch_acf': np.nan,
+                'arch_r2': np.nan,
+                'garch_r2': np.nan
+            }
+
+            return output
     # arch and box test
     x_archtest = arch_stat(x_whitened, m)['arch_lm']
     LBstat = (acf(x_whitened ** 2, nlags=12, fft=False)[1:] ** 2).sum()
@@ -351,7 +354,7 @@ def holt_parameters(x: np.array, freq: int = 1) -> Dict[str, float]:
         fit = ExponentialSmoothing(x, trend='add', seasonal=None).fit()
         params = {
             'alpha': fit.params['smoothing_level'],
-            'beta': fit.params['smoothing_slope']
+            'beta': fit.params['smoothing_trend']
         }
     except:
         params = {
@@ -404,7 +407,7 @@ def hw_parameters(x: np.array, freq: int = 1) -> Dict[str, float]:
         fit = ExponentialSmoothing(x, seasonal_periods=freq, trend='add', seasonal='add').fit()
         params = {
             'hw_alpha': fit.params['smoothing_level'],
-            'hw_beta': fit.params['smoothing_slope'],
+            'hw_beta': fit.params['smoothing_trend'],
             'hw_gamma': fit.params['smoothing_seasonal']
         }
     except:
@@ -694,7 +697,7 @@ def stl_features(x: np.array, freq: int = 1) -> Dict[str, float]:
         deseas = x
         t = np.arange(len(x)) + 1
         try:
-            trend0 = supersmoother(t, deseas)
+            trend0 = SuperSmoother().fit(t, deseas).predict(t)
         except:
             output = {
                 'nperiods': nperiods,
